__all__ = [
    "__title__", "__summary__", "__uri__", "__version__", "__author__",
    "__email__", "__license__", "__copyright__",
]

__title__ = "flme"
__summary__ = "flme: Wrapper of limetr for FHS."
__uri__ = "https://github.com/ihmeuw-msca/lme-for-forecast"

__version__ = "0.0.1"

__author__ = "Jize Zhang"
__email__ = "jizez@uw.edu"

__license__ = "BSD 2-Clause License"
__copyright__ = f"Copyright 2020 {__author__}"
